@@ -16,8 +16,9 @@
 
 #include "vtkAlgorithm.h"
 #include "vtkDICOMModule.h" // For export macro
+#include "vtkDICOMConfig.h" // For configuration details
 #include "vtkDICOMCharacterSet.h" // For character sets
-#include "vtkVersion.h"
+#include "vtkVersion.h" // For changes to pipeline API
 
 class vtkStringArray;
 class vtkIntArray;
@@ -36,11 +37,7 @@ class VTKDICOM_EXPORT vtkDICOMDirectory : public vtkAlgorithm
 {
 public:
   vtkTypeMacro(vtkDICOMDirectory,vtkAlgorithm);
-#ifdef VTK_OVERRIDE
-  void PrintSelf(ostream& os, vtkIndent indent) VTK_OVERRIDE;
-#else
-  void PrintSelf(ostream& os, vtkIndent indent);
-#endif
+  void PrintSelf(ostream& os, vtkIndent indent) VTK_DICOM_OVERRIDE;
   static vtkDICOMDirectory *New();
 
   //! Levels within the DICOM information model.
@@ -125,24 +122,13 @@ public:
    * This method causes the directory to be read.  It must be called before
    * any of the Get methods.
    */
-#ifdef VTK_OVERRIDE
-  void Update() VTK_OVERRIDE { this->Update(0); }
-  void Update(int) VTK_OVERRIDE;
+  void Update() VTK_DICOM_OVERRIDE { this->Update(0); }
+  void Update(int) VTK_DICOM_OVERRIDE;
 #if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION > 0) || VTK_MAJOR_VERSION > 7
-  int Update(vtkInformation *) VTK_OVERRIDE {
+  vtkTypeBool Update(vtkInformation *) VTK_DICOM_OVERRIDE {
     this->Update(); return 1; }
-  int Update(int i, vtkInformationVector *) VTK_OVERRIDE {
+  vtkTypeBool Update(int i, vtkInformationVector *) VTK_DICOM_OVERRIDE {
     this->Update(i); return 1; }
-#endif
-#else
-  void Update() { this->Update(0); }
-  void Update(int);
-#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION > 0) || VTK_MAJOR_VERSION > 7
-  int Update(vtkInformation *) {
-    this->Update(); return 1; }
-  int Update(int i, vtkInformationVector *) {
-    this->Update(i); return 1; }
-#endif
 #endif
   //@}
 
@@ -377,11 +363,8 @@ protected:
   void SetInternalFileName(const char *fname);
 
   //! Set the error code.
-#ifdef VTK_OVERRIDE
-  void SetErrorCode(unsigned long e) VTK_OVERRIDE { this->ErrorCode = e; }
-#else
-  void SetErrorCode(unsigned long e) { this->ErrorCode = e; }
-#endif
+  void SetErrorCode(unsigned long e) VTK_DICOM_OVERRIDE {
+    this->ErrorCode = e; }
 
   //! Add all of the series listed in a DICOMDIR file.
   /*!
@@ -403,15 +386,12 @@ protected:
     vtkDICOMMetaData *meta, const vtkDICOMItem *item, int instance);
 
 private:
-#ifdef VTK_DELETE_FUNCTION
-  vtkDICOMDirectory(const vtkDICOMDirectory&) VTK_DELETE_FUNCTION;
-  void operator=(const vtkDICOMDirectory&) VTK_DELETE_FUNCTION;
-#elif __cplusplus >= 201103L
+#ifdef VTK_DICOM_DELETE
+  vtkDICOMDirectory(const vtkDICOMDirectory&) VTK_DICOM_DELETE;
+  void operator=(const vtkDICOMDirectory&) VTK_DICOM_DELETE;
+#else
   vtkDICOMDirectory(const vtkDICOMDirectory&) = delete;
   void operator=(const vtkDICOMDirectory&) = delete;
-#else
-  vtkDICOMDirectory(const vtkDICOMDirectory&);
-  void operator=(const vtkDICOMDirectory&);
 #endif
 
   struct SeriesItem;
