@@ -39,6 +39,7 @@
 #define SetTupleValue SetTypedTuple
 #endif
 
+vtkStandardNewMacro(vtkDICOMGenerator);
 vtkCxxSetObjectMacro(vtkDICOMGenerator,PatientMatrix,vtkMatrix4x4);
 vtkCxxSetObjectMacro(vtkDICOMGenerator,SourceMetaData,vtkDICOMMetaData);
 vtkCxxSetObjectMacro(vtkDICOMGenerator,UIDGenerator,vtkDICOMUIDGenerator);
@@ -49,6 +50,7 @@ vtkDICOMGenerator::vtkDICOMGenerator()
   this->MetaData = 0;
   this->SourceMetaData = 0;
   this->UIDGenerator = 0;
+  this->Extended = 0;
   this->MultiFrame = 0;
   this->OriginAtBottom = 1;
   this->ReverseSliceOrder = 0;
@@ -180,6 +182,8 @@ void vtkDICOMGenerator::PrintSelf(ostream& os, vtkIndent indent)
   }
   os << indent << "MultiFrame: "
      << (this->MultiFrame ? "On\n" : "Off\n");
+  os << indent << "Extended: "
+     << (this->Extended ? "On\n" : "Off\n");
   os << indent << "OriginAtBottom: "
      << (this->OriginAtBottom ? "On\n" : "Off\n");
   os << indent << "ReverseSliceOrder: "
@@ -220,6 +224,28 @@ vtkDICOMUIDGenerator *vtkDICOMGenerator::GetUIDGenerator()
   return uidgen;
 }
 
+//----------------------------------------------------------------------------
+bool vtkDICOMGenerator::GenerateInstance(vtkInformation *info)
+{
+  this->InitializeMetaData(info);
+  this->CopyAttributes(NULL, this->SourceMetaData);
+
+  // create new SOP instance and series instance UIDs
+  vtkDICOMMetaData *meta = this->MetaData;
+  int n = meta->GetNumberOfInstances();
+  vtkSmartPointer<vtkStringArray> uids =
+    vtkSmartPointer<vtkStringArray>::New();
+  uids->SetNumberOfValues(n);
+  this->GenerateUIDs(DC::SOPInstanceUID, uids);
+  for (int i = 0; i < n; i++)
+  {
+    meta->Set(i, DC::SOPInstanceUID, uids->GetValue(i));
+  }
+  meta->Set(DC::SeriesInstanceUID, this->GenerateUID(DC::SeriesInstanceUID));
+
+  return true;
+}
+
 //----------------------------------------------------------------------------
 std::string vtkDICOMGenerator::GenerateUID(vtkDICOMTag tag)
 {
@@ -527,7 +553,7 @@ void vtkDICOMGenerator::MatchInstances(vtkDICOMMetaData *sourcemeta)
           double v = matrix[4*k +1] - uv[k + 3];
           vv += v*v;
         }
-        if (dd/(spacing[2]*spacing[2]) < 1e-8 &&
+        if (dd/(spacing[2]*spacing[2]) < 1e-6 &&
             uu < 1e-8 && vv < 1e-8)
         {
           this->SourceInstanceArray->SetComponent(i, 0, j);
@@ -832,20 +858,33 @@ void vtkDICOMGenerator::InitializeMetaData(vtkInformation *info)
 
       // If MatchInstances generated a shuffled array, try again with
       // a different dimension ordering.
+      bool switched = false;
       for (int j = 1; j < nframes; j++)
       {
         if (this->SourceInstanceArray->GetComponent(j-1, 0) >
             this->SourceInstanceArray->GetComponent(j, 0))
         {
           switchDimensions = !switchDimensions;
-          continue;
+          switched = true;
+          break;
         }
       }
+      if (switched)
+      {
+        continue;
+      }
     }
 
     break;
   }
 
+  if (this->Extended)
+  {
+    // Copy all attributes, not just ones in the IOD modules for this class.
+    // The module attribute values might be overwritten later.
+    this->CopyAttributes(NULL, this->SourceMetaData);
+  }
+
   this->ComputePixelValueRange(info, this->PixelValueRange);
 }
 
@@ -987,6 +1026,61 @@ bool vtkDICOMGenerator::CopyOptionalAttributes(
   return true;
 }
 
+//----------------------------------------------------------------------------
+bool vtkDICOMGenerator::CopyAttributes(
+  const DC::EnumType *blacklist, vtkDICOMMetaData *source)
+{
+  vtkDICOMMetaData *meta = this->MetaData;
+
+  if (source && source == this->SourceMetaData && this->SourceInstanceArray &&
+      source->Has(DC::PerFrameFunctionalGroupsSequence))
+  {
+    // Not implemented for enhanced multi-frame DICOM files
+  }
+  else if (source)
+  {
+    vtkDICOMDataElementIterator iter = source->Begin();
+    vtkDICOMDataElementIterator iterEnd = source->End();
+    for (;iter != iterEnd; ++iter)
+    {
+      vtkDICOMTag tag = iter->GetTag();
+
+      bool blacklisted = false;
+      if (blacklist)
+      {
+        const DC::EnumType *tags = blacklist;
+        while (*tags != DC::ItemDelimitationItem)
+        {
+          if (*tags++ == tag.GetKey())
+          {
+            blacklisted = true;
+            break;
+          }
+        }
+      }
+
+      if (!blacklisted)
+      {
+        if (!iter->IsPerInstance())
+        {
+          meta->Set(tag, iter->GetValue());
+        }
+        else if (this->SourceInstanceArray && source == this->SourceMetaData)
+        {
+          int n = meta->GetNumberOfInstances();
+          for (int i = 0; i < n; i++)
+          {
+            int j = this->SourceInstanceArray->GetComponent(i, 0);
+            meta->Set(i, tag, iter->GetValue(j));
+          }
+        }
+      }
+    }
+  }
+
+  return true;
+}
+
 //----------------------------------------------------------------------------
 void vtkDICOMGenerator::SetPixelRestrictions(
   unsigned int pixelRepresentation, unsigned int bitsStored,
@@ -1429,7 +1523,9 @@ bool vtkDICOMGenerator::GenerateImagePlaneModule(vtkDICOMMetaData *source)
   meta->Erase(DC::PixelAspectRatio);
   meta->Erase(DC::PatientOrientation);
 
-  meta->Set(DC::PixelSpacing, vtkDICOMValue(vtkDICOMVR::DS, spacing, 2));
+  // DICOM PixelSpacing is RowSpacing,ColumnSpacing
+  double pixelSize[2] = { spacing[1], spacing[0] };
+  meta->Set(DC::PixelSpacing, vtkDICOMValue(vtkDICOMVR::DS, pixelSize, 2));
 
   // this will have to account for image flip, if present
   int n = meta->GetNumberOfInstances();
