@@ -17,7 +17,11 @@ if (!(t)) \
   rval |= 1; \
 }
 
+#ifdef VTK_IN_VTK
+int TestDICOMValue(int argc, char *argv[])
+#else
 int main(int argc, char *argv[])
+#endif
 {
   int rval = 0;
   const char *exename = (argc > 0 ? argv[0] : "TestDICOMValue");
